﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Infragistics.Windows;
using Infragistics.Windows.DataPresenter;
using Quorum.Communicator.Library;
using Quorum.Communicator.DalLinq;
using Quorum.Communicator.Presentation.Data;
using Quorum.Communicator.Presentation.Data.TransactionMessageHistoryTableAdapters;

namespace Quorum.Communicator.Presentation.Controls
{
    /// <summary>
    /// Interaction logic for TranactionMessageHistory.xaml
    /// </summary>
    public partial class TranactionMessageHistory : UserControl
    {
        #region Private Members

        // construct the dataset
        TransactionMessageHistory dataset = new TransactionMessageHistory();
        // use a table adapter to populate the Customers table
        tMessageTransactionTableAdapter adapter = new tMessageTransactionTableAdapter();
        MessageInfo messageInfo;

        #endregion

        #region Constructor

        public TranactionMessageHistory()
        {
            adapter.Connection.ConnectionString = "Data Source=QISWS959\\QISWS959;Initial Catalog=475_Karl;Integrated Security=SSPI;";
            adapter.Fill(dataset.tMessageTransaction, 10, "10264");

            // use the Customer table as the DataContext for this Window
            this.DataContext = dataset.tMessageTransaction.DefaultView;

            InitializeComponent();
        }

        #endregion

        #region Public Methods

        public void Load(MessageInfo messageInfo)
        {
            this.messageInfo = messageInfo;

            Refresh();
        }

        public void Refresh()
        {
            if (messageInfo == null)
                throw new Exception("Can not call the Refresh method without the private member 'messageInfo' being valid.");

            // Check to ensure that transaction information exists in the messageinfo object before trying to retrieve.
            if (!string.IsNullOrEmpty(messageInfo.TransactionId))
            {
                adapter.Connection.ConnectionString = new Database(messageInfo.DatabaseGuid).GetDatabaseConnectionString();
                adapter.Fill(dataset.tMessageTransaction, (int)messageInfo.TransactionType, messageInfo.TransactionId);

                // use the Customer table as the DataContext for this Window
                this.DataContext = dataset.tMessageTransaction.DefaultView;
            }
        }

        #endregion

        #region Event Handlers

        private void Image_PreviewMouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            // pull the binary file from the database and display.
            CellValuePresenter cvp = Utilities.GetAncestorFromType(sender as DependencyObject, typeof(CellValuePresenter), true) as CellValuePresenter;
                       
            // Cast the record passed in as a DataRecord
            DataRecord myRecord = (DataRecord)cvp.Record;            
            //string test = myRecord.Cells[3].Value.ToString();
            string tempFile = new Database(messageInfo.DatabaseGuid).MessageTranactionAttachmentGet(Framework.Validation.ToGuid(myRecord.Cells[3].Value.ToString()));

            System.Diagnostics.Process process = new System.Diagnostics.Process();
            process.StartInfo.UseShellExecute = true;

            // Check to ensure that the file exists.
            if (System.IO.File.Exists(tempFile))
            {
                process.StartInfo.FileName = tempFile;
                process.Start();
                e.Handled = true;
            }
            else
                MessageBox.Show("The file attachment you are attempting to open is invalid.", "File Open Error");
        }
              
        private void imageRefresh_MouseUp(object sender, MouseButtonEventArgs e)
        {
            Refresh();
        }

        #endregion
    }

    /// <summary>
    /// Converter class that converts the true value of the FileExists column to an image to display in the grid control
    /// which the user can then click to open the attached file.
    /// </summary>
    public class MyConverter : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (value != null)
            {
                string fileExtension = value.ToString();
                
                if (fileExtension.ToUpper() == ".DOC")
                    return "../Images/MicrosoftWord.png";
                if (fileExtension.ToUpper() == ".PDF")
                    return "../Images/PDF.png";
                if (fileExtension.ToUpper() == ".CSV")
                    return "../Images/MicrosoftExcel.png";
                if (fileExtension.ToUpper() == ".BMP")
                    return "../Images/Bitmap.png";
                if (!String.IsNullOrEmpty(fileExtension))
                    return "../Images/BlueFileImage.png";
                
                return "";
            }
            return Binding.DoNothing;
        }

        public object ConvertBack(object value, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }

    /// <summary>
    /// Converter class that converts the true value of the Direction column to an image to display in the grid control
    /// informing the user the direction (sent or received) of the message.
    /// </summary>
    public class DirectionConverter : IMultiValueConverter
    {       
        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {
            if (values != null)
            {
                if (values[0] != DependencyProperty.UnsetValue && values[1] != DependencyProperty.UnsetValue)
                {
                    string direction = values[0].ToString();
                    string messageType = values[1].ToString();
                    
                    if (direction.ToUpper() == "INBOUND")
                        if (messageType.ToUpper() == "EMAIL")
                            return "../Images/EmailReceived.png";
                        else
                            return "../Images/SmsSent.png";
                    if (direction.ToUpper() == "OUTBOUND")
                        if (messageType.ToUpper() == "EMAIL")
                            return "../Images/EmailSent.png";
                        else
                            return "../Images/SmsSent.png";               
                }
            }
            return Binding.DoNothing;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}

